
.. py:currentmodule:: pythreejs

DirectionalLightShadow
====================================================

.. Use autoclass to fill any memebers not manually specified.
   This ensures it picks up any members in overridden classes.

.. autohastraits:: DirectionalLightShadow()
    :members:
    :undoc-members:


    Inherits :py:class:`~pythreejs.LightShadow`.

    Three.js docs: https://threejs.org/docs/#api/lights/DirectionalLightShadow


